GeneratedChangedRangeTrace class final

Records direct calls and state outputs of the fourteen operations ported from get_changed_ranges.c. It is optional and has no production overhead.

Properties

events List<(String, Object?)>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
record(String operation, Object? state) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited