GeneratedTreeSitterGrammar class final

Grammar backed by generated Tree-sitter parse tables executed in Dart.

Implemented types

Constructors

GeneratedTreeSitterGrammar({required TreeSitterLanguageTable language, required TreeSitterQuery highlightsQuery, TreeSitterLocalsConfiguration? locals, TreeSitterQuery? injectionsQuery})

Properties

abiVersion int
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hasOutstandingGeneratedParse bool
no setter
highlightsQuery TreeSitterQuery
final
injectionsQuery TreeSitterQuery?
final
language TreeSitterLanguageTable
final
locals TreeSitterLocalsConfiguration?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

convertGenerated(GeneratedTreeSitterNode generated, String source, {bool annotateLocals = true, Uint8List? sourceBytes}) TreeSitterNode
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String source) TreeSitterNode
override
parseGenerated(String source, {GeneratedTreeSitterTree? oldTree, Iterable<TreeSitterInputEdit> edits = const [], List<TreeSitterTableRange> includedRanges = const [], TreeSitterParserRuntimeHooks? runtimeHooks}) GeneratedTreeSitterTree
parseGeneratedUtf8Bytes(Uint8List bytes, {GeneratedTreeSitterTree? oldTree, Iterable<TreeSitterInputEdit> edits = const [], List<TreeSitterTableRange> includedRanges = const [], TreeSitterParserRuntimeHooks? runtimeHooks}) GeneratedTreeSitterTree
resetGeneratedParser() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited