GeneratedTreeSitterNodePosition class final
Effective position of a generated node after all tree edits.
Constructors
- GeneratedTreeSitterNodePosition({required int startByte, required int endByte, required TreeSitterTablePoint startPoint, required TreeSitterTablePoint endPoint})
-
const
Properties
- endByte → int
-
final
- endPoint → TreeSitterTablePoint
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startByte → int
-
final
- startPoint → TreeSitterTablePoint
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited