MutableTreeSitterCancellationToken class final

Mutable token useful when producer and parser execute in the same isolate. Cross-isolate runtimes should implement TreeSitterCancellationToken with their platform's shared cancellation primitive.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
isCancelled bool
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited