TreeSitterAllocator class final

The callback slots controlled by treeSitterSetAllocator.

These callbacks govern buffers explicitly allocated through this object and buffers released by TreeSitterCBufferIterator. They cannot replace the Dart VM's allocator.

Properties

callocCallback TreeSitterCallocFunction
no setter
freeCallback TreeSitterFreeFunction
no setter
hashCode int
The hash code for this object.
no setterinherited
mallocCallback TreeSitterMallocFunction
no setter
reallocCallback TreeSitterReallocFunction
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

calloc(int count, int size) Object?
free(Object? buffer) → void
malloc(int size) Object?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
realloc(Object? buffer, int size) Object?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited