TreeSitterCollectedInput class final

Constructors

TreeSitterCollectedInput({required String source, required int byteLength, required TreeSitterPoint endPoint, Uint8List? sourceBytes, TreeSitterDecodedInputMap? decodedMap})
const

Properties

byteLength int
final
decodedMap TreeSitterDecodedInputMap?
final
endPoint TreeSitterPoint
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
sourceBytes Uint8List?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited