TreeSitterDecodeResult class final

One decoded scalar and the number of source bytes it consumed.

Constructors

TreeSitterDecodeResult(int codePoint, int bytesConsumed)
const

Properties

bytesConsumed int
final
codePoint int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited