TreeSitterDecodedInputMap class final

Boundary map from the UTF-8 parser representation back to the caller's original custom-encoded byte stream.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodedByteForEncodedByte(int encodedByte, {required bool end}) int
decodedUtf16ForDecodedByte(int decodedByte, {required bool end}) int
encodedByteForDecodedByte(int decodedByte, {required bool end}) int
encodedPointForDecodedByte(int decodedByte, {required bool end}) TreeSitterPoint
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited