TreeSitterEditBatch class final

A revisioned sequence of edits, applied strictly in list order.

Constructors

TreeSitterEditBatch({required int baseRevision, required int revision, required Iterable<TreeSitterInputEdit> edits})
TreeSitterEditBatch.fromMessage(Map<Object?, Object?> message)
factory

Properties

baseRevision int
final
edits List<TreeSitterInputEdit>
final
hashCode int
The hash code for this object.
no setterinherited
revision int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMessage() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited