TreeSitterHighlightFatalError class final

Managed fatal counterpart of c_lib.rs::unwrap.

The native C facade writes this diagnostic and aborts the process. Dart cannot provide one target-independent uncatchable abort (especially on web), so it throws an Error while retaining the native diagnostic and ensuring the call cannot be mistaken for an ordinary error-code result.

Inheritance

Constructors

TreeSitterHighlightFatalError(String message)

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited