TreeSitterHighlightItemResult class final

One HighlightIter item, preserving Rust's per-item Result contract.

Properties

error TreeSitterHighlightError?
final
event TreeSitterHighlightEvent?
final
hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
unwrap() TreeSitterHighlightEvent

Operators

operator ==(Object other) bool
The equality operator.
inherited