TreeSitterHtmlHighlight class final

A configured highlight over a UTF-16 range of a Dart String.

This range-oriented type is a convenience adapter for Flutter callers. The native Tree-sitter renderer itself consumes TreeSitterHighlightEvents.

Constructors

TreeSitterHtmlHighlight(int startUtf16, int endUtf16, String scope, {int priority = 0, int order = 0})
const

Properties

endUtf16 int
final
hashCode int
The hash code for this object.
no setterinherited
order int
final
priority int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String
final
startUtf16 int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited