TreeSitterInput class abstract interface

Random-access UTF-8 parser input.

Implementers

Properties

byteLength int
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

byteAt(int byteOffset) int
byteOffsetAtUtf16(int utf16Offset) int
bytesInRange(int startByte, int endByte) Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointAtByte(int byteOffset) TreeSitterPoint
toString() String
A string representation of this object.
inherited
utf16OffsetAtByte(int byteOffset) int

Operators

operator ==(Object other) bool
The equality operator.
inherited