TreeSitterLocalsConfiguration class final
Constructors
- TreeSitterLocalsConfiguration({required TreeSitterQuery query, bool scopeInherits = true})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- query → TreeSitterQuery
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopeInherits → bool
-
final
Methods
-
annotate(
TreeSitterNode root, String source) → TreeSitterNode -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited