TreeSitterNativeLogger class final
Exact value projection of native TSLogger.
Constructors
- TreeSitterNativeLogger({Object? payload, TreeSitterNativeLogCallback? log})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- log → TreeSitterNativeLogCallback?
-
final
- payload → Object?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
TreeSitterLogType type, String message) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited