descendantCount property
int
get
descendantCount
Number of visible nodes in this subtree, including this node.
Implementation
int get descendantCount => walk().length;
Number of visible nodes in this subtree, including this node.
int get descendantCount => walk().length;