TreeSitterParseOptions class final

Constructors

TreeSitterParseOptions({TreeSitterProgressCallback? progressCallback})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
progressCallback TreeSitterProgressCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withProgressCallback(TreeSitterProgressCallback callback) TreeSitterParseOptions
Returns the upstream builder value with callback installed.

Operators

operator ==(Object other) bool
The equality operator.
inherited