TreeSitterParserRuntimeHooks class final

Hooks the core runtime must consume to provide native cancellation, resumable timeout, logging, and graph behavior.

Constructors

TreeSitterParserRuntimeHooks({TreeSitterCancellationToken? cancellationToken, Duration timeout = Duration.zero, TreeSitterLogger? logger, TreeSitterDebugGraphSink? debugGraphSink, TreeSitterParseOptions? parseOptions, TreeSitterParserInternalTrace? internalTrace})
const

Properties

cancellationToken TreeSitterCancellationToken?
final
debugGraphSink TreeSitterDebugGraphSink?
final
hashCode int
The hash code for this object.
no setterinherited
internalTrace TreeSitterDebugGraphSink?
final
logger TreeSitterLogger?
final
parseOptions TreeSitterParseOptions?
final
requiresCoreRuntimeSupport bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited