TreeSitterPoint class final

A zero-based Tree-sitter position. Columns are UTF-8 byte columns.

Implemented types

Constructors

TreeSitterPoint(int row, int column)
const
TreeSitterPoint.fromNative(int row, int column)
Converts the native TSPoint row and column into the public point type.
factory

Properties

column int
final
hashCode int
The hash code for this object.
no setteroverride
row int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(TreeSitterPoint other) int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative() → ({int column, int row})
Converts to native TSPoint fields using Rust's usize as u32 cast.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override