TreeSitterPointRange class final

Constructors

TreeSitterPointRange(TreeSitterPoint start, TreeSitterPoint end)
const

Properties

end TreeSitterPoint
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start TreeSitterPoint
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override