TreeSitterQueryCapture class final

Constructors

TreeSitterQueryCapture({required TreeSitterNode node, required String name, int index = 0, int patternIndex = 0, int priority = 0, Map<String, String?> setProperties = const {}, int order = 0})
const

Properties

debugString String
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
Numeric capture id from the compiled query's capture-name table.
final
name String
final
node TreeSitterNode
final
order int
final
patternIndex int
final
priority int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setProperties Map<String, String?>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited