TreeSitterQueryCaptureOffset class final

Signed Tree-sitter point deltas applied to one capture by #offset!.

Constructors

TreeSitterQueryCaptureOffset({required int startRow, required int startColumn, required int endRow, required int endColumn})
const

Properties

endColumn int
final
endRow int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startColumn int
final
startRow int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited