TreeSitterQueryCompileException class final
- Implemented types
Constructors
- TreeSitterQueryCompileException({required TreeSitterQueryErrorKind kind, required int row, required int column, required int offset, required String message})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited