toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  final prefix = switch (kind) {
    TreeSitterQueryErrorKind.field => 'Invalid field name ',
    TreeSitterQueryErrorKind.nodeType => 'Invalid node type ',
    TreeSitterQueryErrorKind.capture => 'Invalid capture name ',
    TreeSitterQueryErrorKind.predicate => 'Invalid predicate: ',
    TreeSitterQueryErrorKind.structure => 'Impossible pattern:\n',
    TreeSitterQueryErrorKind.syntax => 'Invalid syntax:\n',
    TreeSitterQueryErrorKind.language => '',
  };
  return prefix.isEmpty
      ? message
      : 'Query error at ${row + 1}:${column + 1}. $prefix$message';
}