TreeSitterQueryCursorState class final

Properties

currentByteOffset int
no setter
hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

intoRaw() TreeSitterRawHandle<TreeSitterQueryCursorState>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited