completionByte property

int completionByte
final

Byte position at which the final structural step of this match became definite. Query result ordering uses this rather than the final capture, because required steps do not need to be captured.

Implementation

final int completionByte;