TreeSitterQueryNodePattern class final
One node expression in a structural query. An alternative expression has
alternatives, while _ is represented by isWildcard.
Constructors
-
TreeSitterQueryNodePattern({String? nodeKind, String? supertypeKind, bool isWildcard = false, bool namedOnly = false, bool anonymousOnly = false, bool isMissing = false, List<
TreeSitterQueryNodePattern> alternatives = const [], List<String> captures = const [], List<TreeSitterQueryChildPattern> children = const [], List<String> negatedFields = const [], bool anchorAtEnd = false}) -
const
Properties
-
alternatives
→ List<
TreeSitterQueryNodePattern> -
final
- anchorAtEnd → bool
-
final
- anonymousOnly → bool
-
final
-
captures
→ List<
String> -
final
-
children
→ List<
TreeSitterQueryChildPattern> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMissing → bool
-
final
- isWildcard → bool
-
final
- namedOnly → bool
-
final
-
negatedFields
→ List<
String> -
final
- nodeKind → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supertypeKind → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited