TreeSitterQueryPredicate class final

A text or ancestry constraint attached to a compiled query capture.

Properties

hashCode int
The hash code for this object.
no setterinherited
operator TreeSitterQueryPredicateOperator
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>
final

Methods

matches(String text, List<TreeSitterNode> ancestors, {Set<String> properties = const {}}) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited