TreeSitterQueryPredicateOperator enum

Inheritance
Available extensions

Values

match → const TreeSitterQueryPredicateOperator
notMatch → const TreeSitterQueryPredicateOperator
anyMatch → const TreeSitterQueryPredicateOperator
anyNotMatch → const TreeSitterQueryPredicateOperator
equals → const TreeSitterQueryPredicateOperator
notEquals → const TreeSitterQueryPredicateOperator
anyEquals → const TreeSitterQueryPredicateOperator
anyNotEquals → const TreeSitterQueryPredicateOperator
anyOf → const TreeSitterQueryPredicateOperator
notAnyOf → const TreeSitterQueryPredicateOperator
notHasParent → const TreeSitterQueryPredicateOperator
hasAncestor → const TreeSitterQueryPredicateOperator
notHasAncestor → const TreeSitterQueryPredicateOperator
isProperty → const TreeSitterQueryPredicateOperator
isNotProperty → const TreeSitterQueryPredicateOperator

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TreeSitterQueryPredicateOperator>
A constant List of the values in this enum, in order of their declaration.