TreeSitterQueryProperty class final

A key/value property associated with a compiled query pattern.

Constructors

TreeSitterQueryProperty(String key, {String? value, int? captureId})
const

Properties

captureId int?
final
hashCode int
The hash code for this object.
no setteroverride
key String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override