TreeSitterRange class final

One byte-and-point range accepted by Tree-sitter's included-range API.

Constructors

TreeSitterRange({required int startByte, required int endByte, required TreeSitterPoint startPoint, required TreeSitterPoint endPoint})
const
TreeSitterRange.fromNative({required int startByte, required int endByte, required int startRow, required int startColumn, required int endRow, required int endColumn})
Converts a native TSRange into the public range type.
factory

Properties

endByte int
final
endPoint TreeSitterPoint
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startByte int
final
startPoint TreeSitterPoint
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative() → ({int endByte, ({int column, int row}) endPoint, int startByte, ({int column, int row}) startPoint})
Converts to native TSRange fields using Rust's narrowing casts.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override