TreeSitterReduceActionSet class final

Ordered native-style ReduceActionSet backed by the managed Array(T).

Constructors

TreeSitterReduceActionSet()

Properties

actions List<TreeSitterReduceAction>
no setter
capacity int
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
no setter

Methods

add(TreeSitterReduceAction newAction) → void
Exact ts_reduce_action_set_add uniqueness and insertion-order contract.
delete() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited