TreeSitterScmList class final

Inheritance

Constructors

TreeSitterScmList(int offset, TreeSitterScmListKind kind, List<TreeSitterScmExpression> children)
const

Properties

children List<TreeSitterScmExpression>
final
hashCode int
The hash code for this object.
no setterinherited
kind TreeSitterScmListKind
final
offset int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited