TreeSitterScmQueryParityAuditor class final

Audits the exact operators, predicates, directives, and special selectors accepted by TreeSitterScmHighlightQueryCompiler.

Constructors

TreeSitterScmQueryParityAuditor({Map<String, List<String>> supertypeRelations = const {}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supertypeRelations Map<String, List<String>>
final

Methods

audit(String source) TreeSitterScmQueryParityAudit
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited