TreeSitterScmString class final

Inheritance

Constructors

TreeSitterScmString(int offset, String value, String raw)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
offset int
finalinherited
raw String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited