TreeSitterStructuralQueryPredicate class final
Constructors
- TreeSitterStructuralQueryPredicate({required String? capture, required TreeSitterQueryPredicate predicate, String? otherCapture})
-
const
Properties
- capture → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- otherCapture → String?
-
final
- predicate → TreeSitterQueryPredicate
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited