TreeSitterTagger class final

Owned counterpart of TSTagger and its scope-name language registry.

Constructors

TreeSitterTagger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addLanguage({required String scopeName, required TreeSitterGrammar grammar, required List<int> tagsQuery, List<int>? localsQuery}) TreeSitterTagsError
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
syntaxKindsForScopeName(String scopeName) List<String>?
tag({required String scopeName, required List<int> sourceCode, required TreeSitterTagsBuffer output, TreeSitterTagsCancellationToken? cancellationToken}) TreeSitterTagsError
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited