TreeSitterTreeCursorStatus class final

Query-facing facts computed by C's ts_tree_cursor_current_status.

Constructors

TreeSitterTreeCursorStatus({required int? fieldId, required bool hasLaterSiblings, required bool hasLaterNamedSiblings, required bool canHaveLaterSiblingsWithThisField, required List<int> supertypeIds})
const

Properties

canHaveLaterSiblingsWithThisField bool
final
fieldId int?
final
hashCode int
The hash code for this object.
no setterinherited
hasLaterNamedSiblings bool
final
hasLaterSiblings bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supertypeIds List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited