TreeSitterUtf16Input class final

Constructors

TreeSitterUtf16Input(TreeSitterUtf16InputCallback read, {required TreeSitterUtf16Encoding encoding})
const

Properties

encoding TreeSitterUtf16Encoding
final
hashCode int
The hash code for this object.
no setterinherited
read TreeSitterUtf8InputCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

collect() TreeSitterCollectedInput
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited