TreeSitterUtf16Offset class final

A typed UTF-16 code-unit offset into Tree-sitter source text.

Implemented types

Constructors

TreeSitterUtf16Offset(int value)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

compareTo(TreeSitterUtf16Offset other) int
Compares this object to another object.
override
difference(TreeSitterUtf16Offset other) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator +(int amount) TreeSitterUtf16Offset
operator -(int amount) TreeSitterUtf16Offset
operator ==(Object other) bool
The equality operator.
override