TreeSitterUtf16Range class final

An immutable, half-open UTF-16 source range: [start, end).

Implemented types

Properties

end TreeSitterUtf16Offset
final
hashCode int
The hash code for this object.
no setteroverride
isEmpty bool
no setter
length int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start TreeSitterUtf16Offset
final

Methods

compareTo(TreeSitterUtf16Range other) int
Compares this object to another object.
override
contains(TreeSitterUtf16Offset offset) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override