Grammar whose generated Tree-sitter ABI version can be validated.
- Implemented types
- Implementers
Properties
- abiVersion → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlightsQuery → TreeSitterQuery
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
String source) → TreeSitterNode -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited