TreeSitterWasmEngine class abstract interface

Host-provided WebAssembly engine boundary.

Implementations may use a browser engine, a VM package, or another Dart runtime. The Tree-sitter package itself performs no JS or native interop.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createRuntime(TreeSitterWasmRuntimeConfiguration configuration) TreeSitterWasmRuntime
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited