TreeSitterWasmLanguage class final
Reference-counted language returned from a Wasm store.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisposed → bool
-
no setter
- isWasm → bool
-
no setter
- language → TreeSitterLanguageTable
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
retain(
) → TreeSitterWasmLanguage -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited