TreeSitterWasmResolvedImport class final
Result of the import-name policy used while instantiating a grammar.
Constructors
- TreeSitterWasmResolvedImport(TreeSitterWasmImportSource source, String canonicalName)
-
const
Properties
- canonicalName → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → TreeSitterWasmImportSource
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override