TreeSitterWasmRuntimeConfiguration class final

Constructors

TreeSitterWasmRuntimeConfiguration({required int maximumMemoryPages, required int serializationBufferSize, required List<String> stdlibSymbols, required Set<String> builtinImports, required Set<String> initializerExports})
const

Properties

builtinImports Set<String>
final
hashCode int
The hash code for this object.
no setterinherited
initializerExports Set<String>
final
maximumMemoryPages int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serializationBufferSize int
final
stdlibSymbols List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited