TreeSitterWasmStore class final

Pure-Dart lifecycle and policy layer for a Tree-sitter Wasm store.

Constructors

TreeSitterWasmStore(TreeSitterWasmEngine engine)
factory

Properties

hasError bool
no setter
hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
no setter
languageCount int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

attachLanguageTable(TreeSitterLanguageTable language) bool
Adds the retained wasm module behind language to this store.
callLexKeyword(int state) bool
callLexMain(int state) bool
callScannerCreate() int
callScannerDeserialize(int scannerAddress, List<int> bytes) → void
callScannerDestroy(int scannerAddress) → void
callScannerScan(int scannerAddress, int validTokensIndex) bool
callScannerSerialize(int scannerAddress) Uint8List
dispose() → void
loadLanguage(String name, List<int> bytes) TreeSitterWasmLanguage
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
start(TreeSitterWasmLanguage language) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited