CommentExternalScanner class final

Pure-Dart port of tree-sitter-comment's tag-name scanner, including the implementation pulled into scanner.c through its local parser include.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbols List<int>
finalinherited

Methods

create() StatelessExternalScannerState
inherited
deserialize(StatelessExternalScannerState state, Uint8List data) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scan(StatelessExternalScannerState state, TreeSitterExternalLexer lexer, List<bool> validSymbols) bool
override
serialize(StatelessExternalScannerState state) Uint8List
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited