DExternalScanner class final

Pure-Dart, behavior-preserving port of tree-sitter-d's external scanner.

Implemented types

Constructors

DExternalScanner(TreeSitterLanguageTable language)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbols List<int>
final

Methods

create() DExternalScannerState
override
deserialize(DExternalScannerState state, Uint8List data) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scan(DExternalScannerState state, TreeSitterExternalLexer lexer, List<bool> validSymbols) bool
override
serialize(DExternalScannerState state) Uint8List
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited