ElmExternalScannerState class
final
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
indentLength
↔ int
-
Current line indentation as the pinned scanner's uint32_t.
getter/setter pair
-
indentLengthStack
→ List<int>
-
Layout indentation stack, including the mandatory zero sentinel.
final
-
runback
→ List<int>
-
Pending tokens: 0 = end declaration, 1 = end section.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited