deserialize method
Implementation
@override
void deserialize(HaskellExternalScannerState state, Uint8List data) {
// The pinned scanner does nothing when no complete uint16_t is present;
// in particular, deserializing an empty buffer does not clear the stack.
final count = data.length ~/ 2;
if (count == 0) return;
final bytes = ByteData.sublistView(data);
state.indents
..clear()
..addAll(<int>[
for (var index = 0; index < count; index++)
bytes.getUint16(index * 2, Endian.host),
]);
}