LuaExternalScannerState class final
Constructors
- LuaExternalScannerState({int endingChar = 0, int levelCount = 0})
Properties
- endingChar ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- levelCount ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited