MarkdownInlineExternalScannerState class final
Constructors
- MarkdownInlineExternalScannerState({int parserState = 0, int codeSpanDelimiterLength = 0, int latexSpanDelimiterLength = 0, int numEmphasisDelimitersLeft = 0})
Properties
- codeSpanDelimiterLength ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- latexSpanDelimiterLength ↔ int
-
getter/setter pair
- numEmphasisDelimitersLeft ↔ int
-
getter/setter pair
- parserState ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited