MojoExternalScanner class final

Pure-Dart port of tree-sitter-mojo's scanner at revision 3d7c53b8038f9ebbb57cd2e61296180aa5c1cf64.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbols List<int>
final

Methods

create() MojoExternalScannerState
override
deserialize(MojoExternalScannerState state, Uint8List data) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scan(MojoExternalScannerState state, TreeSitterExternalLexer lexer, List<bool> validSymbols) bool
override
serialize(MojoExternalScannerState state) Uint8List
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited