MojoExternalScannerState class final

Exact serialized state owned by tree-sitter-mojo's native scanner.

Constructors

MojoExternalScannerState({List<int>? indents, List<int>? delimiters, bool insideFString = false})

Properties

delimiters List<int>
final
hashCode int
The hash code for this object.
no setterinherited
indents List<int>
final
insideFString bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited