RstExternalScanner class final

Exact pure-Dart port of the pinned tree-sitter-rst scanner and its included chars.c and parser.c helpers.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbols List<int>
final

Methods

create() RstExternalScannerState
override
deserialize(RstExternalScannerState state, Uint8List data) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scan(RstExternalScannerState state, TreeSitterExternalLexer lexer, List<bool> validSymbols) bool
override
serialize(RstExternalScannerState state) Uint8List
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited