RstExternalScannerState class final
Constructors
-
RstExternalScannerState({List<
int> ? indentStack, int length = 0})
Properties
-
activeIndents
→ List<
int> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indentStack
→ List<
int> -
The pinned C scanner allocates 99 native
intslots.final - length ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited