RubyExternalScannerState class final

Constructors

RubyExternalScannerState({bool hasLeadingWhitespace = false, List<RubyLiteral>? literalStack, List<RubyHeredoc>? openHeredocs})

Properties

hashCode int
The hash code for this object.
no setterinherited
hasLeadingWhitespace bool
getter/setter pair
literalStack List<RubyLiteral>
final
openHeredocs List<RubyHeredoc>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited