RubyHeredoc class final

Constructors

RubyHeredoc({List<int>? word, bool endWordIndentationAllowed = false, bool allowsInterpolation = false, bool started = false})

Properties

allowsInterpolation bool
getter/setter pair
endWordIndentationAllowed bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
started bool
getter/setter pair
word List<int>
Raw bytes, matching the pinned scanner's std::string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited