ScalaExternalScanner class final

Pure-Dart port of the pinned Scala scanner and its stack.h state.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbols List<int>
final

Methods

create() ScalaExternalScannerState
override
deserialize(ScalaExternalScannerState state, Uint8List data) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scan(ScalaExternalScannerState state, TreeSitterExternalLexer lexer, List<bool> validSymbols) bool
override
serialize(ScalaExternalScannerState state) Uint8List
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited