ScalaExternalScannerState class final

Constructors

ScalaExternalScannerState({List<int>? indentationStack, int lastIndentationSize = -1, int lastNewlineCount = 0, int lastColumn = -1})

Properties

depth int
no setter
hashCode int
The hash code for this object.
no setterinherited
indentationStack List<int>
final
lastColumn int
getter/setter pair
lastIndentationSize int
getter/setter pair
lastNewlineCount int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited