TreeSitterFieldMapSlice class final

Constructors

TreeSitterFieldMapSlice(int index, int length)
const
TreeSitterFieldMapSlice.fromJson(Object? json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
final
length int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited