TreeSitterLanguageBundle class final

Provenance and generated parse tables for one Tree-sitter grammar.

Constructors

TreeSitterLanguageBundle({required TreeSitterGrammarRevision source, required String parserSha256, required TreeSitterLanguageTable language})
TreeSitterLanguageBundle.decode(String source)
factory
TreeSitterLanguageBundle.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
language TreeSitterLanguageTable
final
parserSha256 String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source TreeSitterGrammarRevision
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited