TreeSitterLanguageLookaheadIterator class final

Reusable view of terminal symbols accepted in one parse state.

Inheritance

Constructors

TreeSitterLanguageLookaheadIterator(TreeSitterLanguageTable _language, int _state)
TreeSitterLanguageLookaheadIterator.fromRaw(TreeSitterRawHandle<TreeSitterLanguageLookaheadIterator> raw)
Reconstructs ownership of an iterator transferred through intoRaw.
factory

Properties

currentSymbol int
no setter
currentSymbolName String?
no setter
first int
The first element.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
no setter
isEmpty bool
Whether this collection has no elements.
no setterinherited
isNotEmpty bool
Whether this collection has at least one element.
no setterinherited
iterator Iterator<int>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
language TreeSitterLanguageTable
no setter
last int
The last element.
no setterinherited
length int
The number of elements in this Iterable.
no setterinherited
names Iterable<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single int
Checks that this iterable has only one element, and returns that element.
no setterinherited
state int
no setter

Methods

any(bool test(int symbol)) bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) bool
Whether the collection contains an element equal to element.
inherited
dispose() → void
Pure-Dart counterpart of ts_lookahead_iterator_delete.
elementAt(int index) int
Returns the indexth element.
inherited
every(bool test(int symbol)) bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(int element)) Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(int symbol), {int orElse()?}) int
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, int element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<int> other) Iterable<int>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(int element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
intoRaw() TreeSitterRawHandle<TreeSitterLanguageLookaheadIterator>
Moves this iterator, preserving its exact traversal position.
join([String separator = ""]) String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(int symbol), {int orElse()?}) int
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(int e)) Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(int combine(int state, int symbol)) int
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
reset(TreeSitterLanguageTable language, int state) bool
resetState(int state) bool
singleWhere(bool test(int symbol), {int orElse()?}) int
The single element that satisfies test.
inherited
skip(int count) Iterable<int>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(int symbol)) Iterable<int>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) Iterable<int>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(int symbol)) Iterable<int>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) List<int>
Creates a List containing the elements of this Iterable.
inherited
toSet() Set<int>
Creates a Set containing the same elements as this iterable.
inherited
toString() String
Returns a string representation of (some of) the elements of this.
inherited
where(bool test(int symbol)) Iterable<int>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited