TreeSitterLanguageTableEntry class final

Native-shaped result of ts_language_table_entry.

Constructors

TreeSitterLanguageTableEntry({required List<TreeSitterParseAction> actions, required bool reusable})
const

Properties

actionCount int
no setter
actions List<TreeSitterParseAction>
final
hashCode int
The hash code for this object.
no setterinherited
reusable bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited