TreeSitterLexMode class final

Constructors

TreeSitterLexMode({required int lexState, required int externalLexState, required int reservedWordSetId, required int afterWhitespaceLexState})
const
TreeSitterLexMode.fromJson(Map<String, Object?> json)
factory

Properties

afterWhitespaceLexState int
final
externalLexState int
final
hashCode int
The hash code for this object.
no setterinherited
lexState int
final
reservedWordSetId int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited