TreeSitterSymbolMetadata class final

Constructors

TreeSitterSymbolMetadata({required String name, required bool visible, required bool named, required bool supertype, bool generatedRepeatAux = false})
const
TreeSitterSymbolMetadata.fromJson(String name, Map<String, Object?> json)
factory

Properties

generatedRepeatAux bool
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
named bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supertype bool
final
visible bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited