TreeSitterTableToken class final

Constructors

TreeSitterTableToken({required int symbol, required int startByte, required int endByte, required TreeSitterTablePoint startPoint, required TreeSitterTablePoint endPoint, required String text, int? lookaheadEndByte, int? unexpectedCharacter, bool explicitEnd = false})
const

Properties

effectiveLookaheadEndByte int
no setter
endByte int
final
endPoint TreeSitterTablePoint
final
explicitEnd bool
final
hashCode int
The hash code for this object.
no setterinherited
isEof bool
no setter
lookaheadEndByte int?
Furthest byte inspected while deciding this token, matching ts_lexer_finish's lookahead_end_byte accumulator.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startByte int
final
startPoint TreeSitterTablePoint
final
symbol int
final
text String
final
unexpectedCharacter int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withLookaheadEndByte(int value) TreeSitterTableToken

Operators

operator ==(Object other) bool
The equality operator.
inherited