TypstExternalScannerState class final

Constructors

TypstExternalScannerState({List<int>? indentation, List<int>? containers, List<int>? worker, bool immediate = false, int headingLevel = 0, bool lineStart = false})

Properties

containers List<int>
final
hashCode int
The hash code for this object.
no setterinherited
headingLevel int
getter/setter pair
immediate bool
getter/setter pair
indentation List<int>
final
lineStart bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
worker List<int>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited