YamlExternalScannerState class final

Constructors

YamlExternalScannerState({int row = 0, int column = 0, int blockImplicitRow = -1, int blockImplicitColumn = -1, int blockImplicitHasTab = 0, List<int>? indentationTypes, List<int>? indentationLengths})

Properties

blockImplicitColumn int
getter/setter pair
blockImplicitHasTab int
getter/setter pair
blockImplicitRow int
getter/setter pair
column int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
indentationLengths List<int>
final
indentationTypes List<int>
final
row int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited