GeneratedChangedRangeTrace class final
Records direct calls and state outputs of the fourteen operations ported
from get_changed_ranges.c. It is optional and has no production overhead.
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
record(
String operation, Object? state) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited