GeneratedEditedSubtreeState class final
Effective relative subtree fields after ts_subtree_edit.
Constructors
- GeneratedEditedSubtreeState({required int paddingBytes, required TreeSitterTablePoint paddingExtent, required int sizeBytes, required TreeSitterTablePoint sizeExtent, required int lookaheadBytes, required bool hasChanges})
-
const
Properties
- hasChanges → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lookaheadBytes → int
-
final
- paddingBytes → int
-
final
- paddingExtent → TreeSitterTablePoint
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeBytes → int
-
final
- sizeExtent → TreeSitterTablePoint
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited