TreeSitterBufferTag class final
Flat TSTag representation stored by the C tags-buffer API.
Constructors
- TreeSitterBufferTag({required int startByte, required int endByte, required int nameStartByte, required int nameEndByte, required int lineStartByte, required int lineEndByte, required TreeSitterPoint startPoint, required TreeSitterPoint endPoint, required int utf16StartColumn, required int utf16EndColumn, required int docsStartByte, required int docsEndByte, required int syntaxTypeId, required bool isDefinition})
-
const
Properties
- docsEndByte → int
-
final
- docsStartByte → int
-
final
- endByte → int
-
final
- endPoint → TreeSitterPoint
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDefinition → bool
-
final
- lineEndByte → int
-
final
- lineStartByte → int
-
final
- nameEndByte → int
-
final
- nameStartByte → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startByte → int
-
final
- startPoint → TreeSitterPoint
-
final
- syntaxTypeId → int
-
final
- utf16EndColumn → int
-
final
- utf16StartColumn → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited