TreeSitterHighlightEvent class sealed

One event in Tree-sitter's streaming highlight protocol.

Implementers

Constructors

TreeSitterHighlightEvent.end()
const
factory
TreeSitterHighlightEvent.source({required int start, required int end})
const
factory
TreeSitterHighlightEvent.start(TreeSitterHighlight highlight)
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited