TreeSitterHighlighter class final
Reusable highlighter state. The parser is retained across calls, matching
Tree-sitter's Highlighter; query cursors are managed Dart iterables.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- parser → TreeSitterParser
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void - Releases reusable state owned by a C-style highlight buffer.
-
highlight(
TreeSitterHighlightConfiguration configuration, String source, {TreeSitterHighlightCancellationToken? cancellationToken, TreeSitterHighlightInjectionCallback? injectionCallback}) → Iterable< TreeSitterHighlightItemResult> -
highlightByteEvents(
TreeSitterHighlightConfiguration configuration, Uint8List sourceBytes, {TreeSitterHighlightCancellationToken? cancellationToken, TreeSitterHighlightInjectionCallback? injectionCallback}) → Iterable< TreeSitterHighlightEvent> -
highlightBytes(
TreeSitterHighlightConfiguration configuration, Uint8List sourceBytes, {TreeSitterHighlightCancellationToken? cancellationToken, TreeSitterHighlightInjectionCallback? injectionCallback}) → Iterable< TreeSitterHighlightItemResult> - Highlights exact UTF-8 bytes while retaining their native byte offsets.
-
highlightEvents(
TreeSitterHighlightConfiguration configuration, String source, {TreeSitterHighlightCancellationToken? cancellationToken, TreeSitterHighlightInjectionCallback? injectionCallback}) → Iterable< TreeSitterHighlightEvent> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited