TreeSitterHtmlHighlight class final
A configured highlight over a UTF-16 range of a Dart String.
This range-oriented type is a convenience adapter for Flutter callers. The native Tree-sitter renderer itself consumes TreeSitterHighlightEvents.
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited