TreeSitterNativeInput class final
Exact value projection of native TSInput for the pure-Dart runtime.
Constructors
- TreeSitterNativeInput({Object? payload, required TreeSitterNativeInputRead? read, required TreeSitterInputEncoding encoding, TreeSitterDecodeFunction? decode})
-
const
Properties
- decode → TreeSitterDecodeFunction?
-
final
- encoding → TreeSitterInputEncoding
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- payload → Object?
-
final
- read → TreeSitterNativeInputRead?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readAt(
int byteOffset, TreeSitterPoint position) → List< int> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited