TreeSitterNativeParseOptions class final
Exact value projection of native TSParseOptions.
Constructors
- TreeSitterNativeParseOptions({Object? payload, TreeSitterNativeProgressCallback? progressCallback})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- payload → Object?
-
final
- progressCallback → TreeSitterNativeProgressCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldHalt(
int currentByteOffset, {required bool hasError}) → bool -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited