TreeSitterNativeParseState class final

Exact value projection of the callback-owned native TSParseState.

Implemented types

Constructors

TreeSitterNativeParseState({Object? payload, required int currentByteOffset, required bool hasError})
const
TreeSitterNativeParseState.fromRaw(TreeSitterRawHandle<TreeSitterNativeParseState> raw)
factory

Properties

currentByteOffset int
final
hasError bool
final
hashCode int
The hash code for this object.
no setterinherited
payload Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

intoRaw() TreeSitterRawHandle<TreeSitterNativeParseState>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited