TreeSitterQueryCaptureResult class final
One item from a lazy query-capture stream.
All captures belonging to the same query match share match. Calling TreeSitterQueryMatch.remove suppresses the remaining captures for that match without affecting captures that have already been returned.
Constructors
- TreeSitterQueryCaptureResult({required TreeSitterQueryMatch match, required int captureIndex})
-
const
Properties
- capture → TreeSitterQueryCapture
-
no setter
- captureIndex → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- match → TreeSitterQueryMatch
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited