TreeSitterQueryChildPattern class final

Constructors

TreeSitterQueryChildPattern({TreeSitterQueryNodePattern? pattern, List<TreeSitterQueryChildPattern> group = const [], TreeSitterQueryQuantifier quantifier = TreeSitterQueryQuantifier.one, String? fieldName, bool anchorBefore = false})
const

Properties

anchorBefore bool
No named sibling may occur between this item and the preceding item. On the first item, no named sibling may occur before it.
final
fieldName String?
final
group List<TreeSitterQueryChildPattern>
final
hashCode int
The hash code for this object.
no setterinherited
pattern TreeSitterQueryNodePattern?
final
quantifier TreeSitterQueryQuantifier
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited