anchorBefore property
No named sibling may occur between this item and the preceding item. On the first item, no named sibling may occur before it.
Implementation
final bool anchorBefore;
No named sibling may occur between this item and the preceding item. On the first item, no named sibling may occur before it.
final bool anchorBefore;