TreeSitterQueryPattern class final
Constructors
Properties
- capture → String
-
final
- childIndex → int?
-
final
- fieldName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nodeKind → String
-
final
- parentKind → String?
-
final
- patternIndex → int
-
final
-
predicates
→ List<
TreeSitterQueryPredicate> -
final
- priority → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
setProperties
→ Map<
String, String?> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited