TreeSitterReduceAction class final
Managed field-for-field counterpart of native ReduceAction.
Constructors
- TreeSitterReduceAction({required int count, required int symbol, required int dynamicPrecedence, required int productionId})
-
const
Properties
- count → int
-
final
- dynamicPrecedence → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- productionId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbol → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited