TreeSitterStructuralQueryPattern class final

A complete structural query pattern used when a Scheme query contains sibling anchors or quantifiers and cannot be represented as one contextual capture.

Constructors

TreeSitterStructuralQueryPattern({required TreeSitterQueryNodePattern? root, int patternIndex = 0, List<TreeSitterQueryChildPattern> rootSiblings = const [], bool rootAnchorAtEnd = false, List<TreeSitterStructuralQueryPredicate> predicates = const [], int priority = 0, Map<String, String?> setProperties = const {}, Map<String, TreeSitterQueryCaptureOffset> captureOffsets = const {}})
const

Properties

captureOffsets Map<String, TreeSitterQueryCaptureOffset>
final
hashCode int
The hash code for this object.
no setterinherited
patternIndex int
final
predicates List<TreeSitterStructuralQueryPredicate>
final
priority int
final
root TreeSitterQueryNodePattern?
final
rootAnchorAtEnd bool
final
rootSiblings List<TreeSitterQueryChildPattern>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setProperties Map<String, String?>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited