TreeSitterWasmInstantiation class final
Constructors
- TreeSitterWasmInstantiation({required TreeSitterLanguageTable language, required TreeSitterWasmModule module, required TreeSitterWasmLanguageInstance instance})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- instance → TreeSitterWasmLanguageInstance
-
final
- language → TreeSitterLanguageTable
-
final
- module → TreeSitterWasmModule
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited