TreeSitterWasmLanguageInstance class abstract interface

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
lexKeyword(int state) bool
lexMain(int state) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scannerCreate() int
scannerDeserialize(int scannerAddress, Uint8List bytes) → void
scannerDestroy(int scannerAddress) → void
scannerScan(int scannerAddress, int validTokensIndex) bool
scannerSerialize(int scannerAddress) Uint8List
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited