BashExternalScannerState class final
Constructors
-
BashExternalScannerState({int lastGlobParenDepth = 0, bool extWasInDoubleQuote = false, bool extSawOutsideQuote = false, List<
BashHeredoc> ? heredocs})
Properties
- extSawOutsideQuote ↔ bool
-
getter/setter pair
- extWasInDoubleQuote ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
heredocs
→ List<
BashHeredoc> -
final
- lastGlobParenDepth ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited