JustExternalScannerState class final
Constructors
- JustExternalScannerState({int previousIndent = 0, int advanceBraceCount = 0, bool hasSeenEndOfFile = false, int paddingByte = 0})
Properties
- advanceBraceCount ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSeenEndOfFile ↔ bool
-
getter/setter pair
- paddingByte ↔ int
-
The pinned scanner serializes its raw C struct, including one padding
byte. Retaining it makes deserialize/serialize byte-exact.
getter/setter pair
- previousIndent ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited