TreeSitterExternalLexer class final
Dart counterpart of Tree-sitter's TSLexer external-scanner surface.
Constructors
-
TreeSitterExternalLexer(String source, {int position = 0, TreeSitterTablePoint point = const TreeSitterTablePoint(0, 0), List<
int> ? sourceBytes, TreeSitterTableInputRefill? refill, List<TreeSitterTableRange> includedRanges = const [], void logger(String message)?})
Properties
-
bytes
→ List<
int> -
final
- column → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAtIncludedRangeStart → bool
-
no setter
- isEof → bool
-
no setter
- lookahead → int
-
no setter
- lookaheadEndByte → int
-
Exact
ts_lexer_finishboundary for this scan attempt.no setter - point → TreeSitterTablePoint
-
no setter
- position → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
advance(
{required bool skip}) → void -
advanceSpaces(
{required bool skip}) → int -
advanceUntilNewline(
{required bool skip}) → int -
log(
String message) → void -
Native
TSLexer.logfor grammar-specific external scanners. -
markEnd(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setResultSymbol(
int symbol) → void -
token(
) → TreeSitterTableToken? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited