TreeSitterLanguageBundle constructor
TreeSitterLanguageBundle({
- required TreeSitterGrammarRevision source,
- required String parserSha256,
- required TreeSitterLanguageTable language,
Implementation
TreeSitterLanguageBundle({
required this.source,
required this.parserSha256,
required this.language,
}) {
// In native Tree-sitter, a generated language's parse tables and external
// scanner are compiled from the same grammar revision. Keep that binding
// when the portable table is decoded so scanner ports can faithfully
// select between supported scanner revisions with the same token ABI.
language._grammarRevision = source.revision;
}