TreeSitterLexState class final
Constructors
-
TreeSitterLexState({required int acceptToken, required bool acceptsEnd, required int acceptPriority, required bool skip, required int defaultState, required int eofState, required List<
TreeSitterLexTransition> transitions}) -
const
-
TreeSitterLexState.fromJson(Map<
String, Object?> json, {bool acceptsEnd = false}) -
factory
Properties
- acceptPriority → int
-
final
- acceptsEnd → bool
-
final
- acceptToken → int
-
final
- defaultState → int
-
final
- eofState → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skip → bool
-
final
-
transitions
→ List<
TreeSitterLexTransition> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited